
Examples
========


Crawler
-------

A cooperative i/o library wouldn't be such without a "crawler" example:

.. literalinclude:: ../examples/crawler.py


Echo server
-----------

.. literalinclude:: ../examples/echo-server.py

